import { useState, useCallback, useEffect,  } from "react"

/*
  TODO: Poll(uri, flavour)
  - uri: string
  - execution_flvour:
    - once (i.e. now)
    - interval (sec)
    - stop
*/

export default function Poll(url, interval_sec, disabled) {
    const [cache, setCache] = useState(null)
    const [fetching, setFetching] = useState(false)
    const [timeoutID, setTimeoutID] = useState(null)

    const fecthData = useCallback(() => {
        setTimeoutID(null)
        setFetching(true)

        fetch(url)
            .then((response) => {
                setFetching(false)
                return response.json()
            })
            .then((freshData) => setCache(freshData))
            .catch((err) => console.log(err.message))
    }, [url])

    useEffect(() => {
        if (cache == null) {
            fecthData()  // <<-- run immediatly on startup
        }
        else if (disabled === true) {
            clearTimeout(timeoutID) // cancel already scheduled fetch
            setTimeoutID(null)
        }
        else if (timeoutID === null) {
            const timeoutID = setTimeout(fecthData, interval_sec * 1000)
            setTimeoutID(timeoutID)
            console.log("Fetch '" +url +"' scheduled in " +interval_sec +" sec")
        }
    }, [url, cache, fecthData, timeoutID, disabled, interval_sec]);

    return {
        data: cache,
        fetching
    }
}
